@@ -11,6 +11,8 @@ from .cifar10.model_vgg import vgg_cifar10, vgg_cifar10_pretrained
 from .imagenet.model_mobilenet import (mobilenet_imagenet,
                                        mobilenet_imagenet_pretrained,
                                        mobilenet_cats_vs_dogs_pretrained)
+from .imagenet.model_vgg import (vgg_imagenet, vgg_imagenet_pretrained,
+                                 vgg_melanoma_pretrained)
 from .imagenet.model_mobilenet_edge import (mobilenet_edge_imagenet,
                                             mobilenet_edge_imagenet_pretrained)
 from .kws.model_ds_cnn import ds_cnn_kws, ds_cnn_kws_pretrained
