@@ -35,7 +35,7 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
                    weight_quantization=0,
                    activ_quantization=0,
                    input_weight_quantization=None):
-    """Instantiates a MobileNet-like model for the "Cifar-10" example.
+    """Instantiates a MobileNet-like model for the "CIFAR-10" example.
     This model is based on the MobileNet architecture, mainly with fewer layers.
     The weights and activations are quantized such that it can be converted into
     an Akida model.
@@ -65,7 +65,7 @@ def ds_cnn_cifar10(input_shape=(32, 32, 3),
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
 
     Returns:
-        tf.keras.Model: a quantized Keras model for DS-CNN/cifar10
+        tf.keras.Model: a Keras model for DS-CNN/CIFAR-10
     """
 
     # Overrides input weight quantization if None
