@@ -29,6 +29,7 @@ from .cifar10.model_vgg import vgg_cifar10
 from .utk_face.model_vgg import vgg_utk_face
 from .kws.model_ds_cnn import ds_cnn_kws
 from .imagenet.model_mobilenet import mobilenet_imagenet
+from .imagenet.model_vgg import vgg_imagenet
 from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
 from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny_handy import convtiny_dvs_handy
@@ -97,6 +98,12 @@ def main():
                            type=int,
                            default=1000,
                            help="The number of classes")
+    vgg_parser = csp.add_parser("vgg_imagenet", help="A VGG model for akida")
+    vgg_parser.add_argument("-c",
+                            "--classes",
+                            type=int,
+                            default=1000,
+                            help="The number of classes")
     mbe_parser = csp.add_parser("mobilenet_imagenet_edge",
                                 help="A MobileNet V1 model modified for akida \
                                edge learning")
@@ -156,6 +163,8 @@ def main():
                                        classes=args.classes)
             if model_path is None:
                 model_path = f"{model.name}.h5"
+        elif args.model == "vgg_imagenet":
+            model = vgg_imagenet(classes=args.classes)
         elif args.model == "mobilenet_imagenet_edge":
             model = mobilenet_edge_imagenet(base_model=args.base_model,
                                             classes=args.classes)
