@@ -22,9 +22,12 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 # ******************************************************************************
+"""
+Data generator for YOLO training.
+"""
 
-import cv2
 import copy
+import cv2
 import numpy as np
 
 from imgaug import augmenters as iaa
@@ -196,6 +199,21 @@ class BatchGenerator(Sequence):
             np.random.shuffle(self._data)
 
     def aug_image(self, train_instance, jitter):
+        """ Performs data augmentation on an image.
+
+        Args:
+            train_instance (dict): the dictionnary of input data (image and
+             boxes)
+            jitter (bool): enable jitter in the augmentation pipeline
+
+        Raises:
+            ValueError: if the number of channel in the input shape is wrong
+             (ie. different from 1 or 3).
+            RuntimeError: if the image cannot be found
+
+        Returns:
+            tuple: the augmented image and the associated boxes
+        """
         image_path = train_instance['image_path']
         if self._input_shape[2] == 1:
             image = cv2.imread(image_path, cv2.IMREAD_GRAYSCALE)
