@@ -27,6 +27,31 @@ import numpy as np
 
 
 class DVS_DataGenerator:
+    """ Data generator for handling event-based camera data.
+
+    Args:
+        dataset (array): array of data stored in a dict.
+        inversion (bool, optional): flag to flip x/y coords.
+        packets_fixed_by (str, optional): value used to fix packet length, one
+            of 'duration' or (number of) 'events'. Defaults to 'duration'.
+        subpacket_length (int, optional): subpacket length (milliseconds if
+            packets_fixed_by='duration', event count if 'events'). Defaults to
+            100.
+        subpackets_per_packet (int, optional): number of sub-packets (~ time
+            bins) to concatenate to generate packets. Defaults to 1.
+        camera_dims (tuple of ints, optional): dimensions of the raw data from
+            the camera. Defaults to (128, 128, 2).
+        include_polarity (bool, optional): keep event polarity. If False, On and
+            Off events will be treated as if identical. Defaults to True.
+        allow_duplicate_events (bool, optional): allow events to be
+            superimposed. If False, only a single event will be allowed per
+            pixel for each timebin (subpacket) and polarity. Default to False.
+        downscale (int, optional): downscaling of inputs, implemented as integer
+            division of incoming coordinate values. Defaults to 1.
+
+    Returns:
+        tuple: two numpy arrays with events and labels.
+    """
 
     def __init__(self,
                  dataset,
@@ -38,30 +63,6 @@ class DVS_DataGenerator:
                  include_polarity=True,
                  allow_duplicate_events=False,
                  downscale=1):
-        """
-        Data generator for handling event-based camera data.
-        Args:
-            dataset (array): array of data stored in a dict.
-            inversion (bool): flag to flip x/y coords.
-            packets_fixed_by (str, def: 'duration'): value used to fix packet
-                length, one of 'duration' or (number of) 'events'.
-            subpacket_length (int, def: 100): subpacket length (milliseconds if
-                packets_fixed_by='duration', event count if 'events').
-            subpackets_per_packet (int, def: 1): number of sub-packets
-                (~ time bins) to concatenate to generate packets.
-            camera_dims (tuple of ints, def: (128, 128, 2)): dimensions of the
-                raw data from the camera.
-            include_polarity (bool, def: True): keep event polarity.
-                If False, On and Off events will be treated as if identical.
-            allow_duplicate_events (bool, def: False): allow events to be
-                superimposed. If False, only a single event will be allowed per
-                pixel for each timebin (subpacket) and polarity.
-            downscale (int, def: 1): downscaling of inputs, implemented as
-                integer division of incoming coordinate values.
-
-        Returns:
-            tuple: two numpy arrays with events and labels.
-        """
         self.packets_fixed_by = packets_fixed_by
         if packets_fixed_by.startswith('dur'):
             # Convert milliseconds to microseconds
@@ -81,7 +82,7 @@ class DVS_DataGenerator:
         self.allow_duplicate_events = allow_duplicate_events
 
         self.dataset = dataset
-        if inversion == False:
+        if not inversion:
             # DVS gesture dataset is described and provided (and loaded) with
             # classes indexed from 1, not 0.
             # This modifier corrects for that offset
@@ -118,14 +119,25 @@ class DVS_DataGenerator:
                            class_list,
                            class_key=None,
                            samples_per_trial=5):
-        # Generate [samples_per_trial] samples from each subject/lighting
-        # condition/class
+        """ Generates [samples_per_trial] samples from each subject/lighting
+        condition/class.
+
+        Args:
+            class_list (list): classes selected for training
+            class_key (list, optional): keys of selected classes. Defaults to
+             None.
+            samples_per_trial (int, optional): number of times that every sample
+             have to be repeated. Defaults to 5.
+
+        Returns:
+            tuple: events and labels
+        """
         if class_key is None:
             class_key = list(range(len(class_list)))
         outevents = []
         outlabels = []
         sample_windows = []
-        for ind, trial in enumerate(self.dataset):
+        for _, trial in enumerate(self.dataset):
             if int(trial['label']) in class_list:
                 # Get latest start point (valid across all repeats)
                 num_events = trial['ev_times'].shape[0]
@@ -133,9 +145,8 @@ class DVS_DataGenerator:
                     latest_start_time = trial['ev_times'][-1] - (
                         self.subpacket_length * self.subpackets_per_packet)
                     if latest_start_time < 0:
-                        print(
-                            'ERROR: Sample durations requested is longer than the available data for this trial'
-                        )
+                        print('ERROR: Sample durations requested is longer \
+                            than the available data for this trial')
                         continue
                     latest_start_point = np.searchsorted(np.squeeze(
                         trial['ev_times']),
@@ -149,7 +160,7 @@ class DVS_DataGenerator:
                     continue
 
                 # Build samples from multiple packets
-                for rr in range(samples_per_trial):
+                for _ in range(samples_per_trial):
                     sample_evs = np.zeros((0, 3), dtype=np.uint8)
                     start_point = np.random.randint(latest_start_point)
                     sample_start_point = start_point
@@ -215,35 +226,45 @@ class DVS_DataGenerator:
                               class_key=None,
                               start_time=0,
                               stop_time=None):
-        # Generate series of temporally contiguous samples from a single
-        # subject+class
-        if class_key == None:
+        """ Generates series of temporally contiguous samples from a single
+        subject+class.
+
+        Args:
+            subj (int): subject id
+            class_label (int): label of the class
+            class_key (int, optional): key of the class. Defaults to None.
+            start_time (int, optional): samples starting point. Defaults to 0.
+            stop_time (int, optional): samples ending point. Defaults to None.
+
+        Returns:
+            tuple: events, labels, plot events
+        """
+        if class_key is None:
             class_key = class_label
         outevents = []
         outlabels = []
         plotevents = []
         sample_windows = []
-        for ind, trial in enumerate(self.dataset):
+        for _, trial in enumerate(self.dataset):
             local_stop_time = stop_time
             if (int(trial['label']) == class_label) and (int(trial['subject'])
                                                          == subj):
                 # Get latest start point (valid across all repeats)
                 num_events = trial['ev_times'].shape[0]
-                if local_stop_time == None:
+                if local_stop_time is None:
                     local_stop_time = trial['ev_times'][-1]
                 elif local_stop_time > trial['ev_times'][-1]:
-                    print(
-                        'ERROR: requested stop time later than the end of the trial'
-                    )
+                    print('ERROR: requested stop time later than the end of \
+                         the trial')
                     print('Ending samples at ' + str(trial['ev_times'][-1]))
                     local_stop_time = trial['ev_times'][-1]
                 if self.packets_fixed_by.startswith('dur'):
                     latest_start_time = local_stop_time - \
                         (self.subpacket_length * self.subpackets_per_packet)
                     if latest_start_time < 0:
-                        print(
-                            'ERROR: Sample durations requested is longer than the available data for this trial (or stop time is set too early)'
-                        )
+                        print('ERROR: Sample durations requested is longer \
+                            than the available data for this trial (or stop \
+                            time is set too early)')
                         continue
                     latest_start_point = np.searchsorted(np.squeeze(
                         trial['ev_times']),
@@ -321,8 +342,13 @@ class DVS_DataGenerator:
         return outevents, outlabels, plotevents
 
     def events2matrix(self, event_packet):
-        """Transforms a list of DVS aer events into a matrix suitable for
-            TensorFlow training
+        """ Transforms a DVS aer event into a numpy array.
+
+        Args:
+            event_packet (numpy.ndarray): input events packet
+
+        Returns:
+            numpy.ndarray: matrix of events
         """
         if self.allow_duplicate_events:
             out_mat = np.zeros((self.sample_dims))
@@ -340,6 +366,15 @@ class DVS_DataGenerator:
         return out_mat.astype(np.float16)
 
     def samples_evs2images(self, samples_events):
+        """ Transforms a list of DVS aer events into a matrix suitable for
+        TensorFlow training.
+
+        Args:
+            samples_events (list): list of DVS events
+
+        Returns:
+            np.ndarray: events as an image array
+        """
         outmat = []
         for sample in samples_events:
             sample_mat = self.events2matrix(sample)
@@ -354,6 +389,26 @@ class DVS_DataGenerator:
                      rotation_range=0,
                      width_shift_range=1.0,
                      height_shift_range=1.0):
+        """ Performs data augmentations on sample events.
+
+        Args:
+            samples_events (list): list of DVS events to process
+            horizontal_flip (bool, optional): enable horizontal flip. Defaults
+             to False.
+            vertical_flip (bool, optional): enable vertical flip. Defaults to
+             False.
+            polarity_flip (bool, optional): enable polarity flip. Defaults to
+             False.
+            rotation_range (int, optional): rotation angle range in degrees.
+             Defaults to 0.
+            width_shift_range (float, optional): range of width shift. Defaults
+             to 1.0.
+            height_shift_range (float, optional): range of height shift.
+             Defaults to 1.0.
+
+        Returns:
+            list: augmented events
+        """
         outevents = []
         for sample in samples_events:
             samp = np.copy(sample).astype(np.float)
