@@ -147,11 +147,10 @@ def mobilenet_imagenet(input_shape=None,
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
 
     Returns:
-        A Keras model instance.
+        tf.keras.Model: a Keras model for MobileNet/ImageNet.
 
     Raises:
-        ValueError: in case of invalid argument for `weights`,
-            or invalid input shape.
+        ValueError: in case of invalid input shape.
     """
     # check if overrides have been provided and override
     if input_weight_quantization is None:
