@@ -18,9 +18,6 @@
 This model is an adaptation of the `mobilenet_imagenet` model for edge
 applications. It is based on MobileNetBC with top layers replaced by a quantized
 spike extractor and a classification layer.
-
-It comes with a `mobilenet_edge_imagenet_pretrained` helper method that loads a
-set of pretrained weights on a Mobilenet 0.5 that can be run on Akida hardware.
 """
 
 # Tensorflow/Keras imports
@@ -55,9 +52,9 @@ def mobilenet_edge_imagenet(base_model, classes):
         base_classifier = base_model.get_layer("separable_14")
         # remember the classifier weight bitwidth
         wq = base_classifier.quantizer.bitwidth
-    except:
-        raise ValueError(
-            "The base model is not a quantized Mobilenet/Imagenet model")
+    except Exception as e:
+        raise ValueError("The base model is not a quantized \
+                          Mobilenet/Imagenet model") from e
 
     # Recreate a model with all layers up to the classifier
     x = base_classifier.input
@@ -79,7 +76,8 @@ def mobilenet_edge_imagenet(base_model, classes):
                     add_activation=False,
                     add_batchnorm=False,
                     use_bias=False)
-    x = Activation('softmax', name='act_softmax')(x)
+    act_function = 'softmax' if classes > 1 else 'sigmoid'
+    x = Activation(act_function, name=f'act_{act_function}')(x)
     x = Reshape((classes,), name='reshape_2')(x)
 
     # Create model
@@ -99,8 +97,15 @@ def mobilenet_edge_imagenet(base_model, classes):
 
 
 def mobilenet_edge_imagenet_pretrained():
-    model_name = 'mobilenet_imagenet_alpha_50_edge_iq8_wq4_aq4.h5'
-    file_hash = '6DB45B6D786210637C97CAC4DF3CE788AC5C02035D82099731B1EDFEF3CFD4AF'
+    """ Helper method to retrieve a `mobilenet_edge_imagenet` model that was
+    trained on ImageNet dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'mobilenet_imagenet_224_alpha_50_edge_iq8_wq4_aq4.h5'
+    file_hash = 'f2d062221741aa538b897016459df1ed93f28d666ea90fbb699b5b8d57fec5e5'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
