@@ -12,7 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Provides utilities to preprocess images.
+"""
+Provides utilities to preprocess images.
 
 Training images are sampled using the provided bounding boxes, and subsequently
 cropped to the sampled bounding box. Images are additionally flipped randomly,
@@ -33,7 +34,8 @@ Brainchip changes:
         - Original file: https://github.com/tensorflow/models/blob/master/official/vision/image_classification/imagenet_preprocessing.py
         - Update preprocess_image() return value for Akida compatibility
         - Change cycle_length 'parallelization' parameter
-        - Add _distort_color, _apply_with_random_selector, and _random_distort_color methods
+        - Add _distort_color, _apply_with_random_selector, and
+          _random_distort_color methods
           from https://github.com/tensorflow/models/blob/master/research/slim/preprocessing/inception_preprocessing.py
 """
 
@@ -44,10 +46,9 @@ from __future__ import print_function
 import os
 from absl import logging
 import tensorflow as tf
-import sys
 import numpy as np
 
-from tensorflow.python.ops import control_flow_ops
+from tensorflow.python.ops import control_flow_ops  # pylint: disable=no-name-in-module
 from .imagenet_labels2names import imagenet_labels
 
 NUM_CHANNELS = 3
@@ -73,7 +74,6 @@ def process_record_dataset(dataset,
                            im_size,
                            shuffle_buffer,
                            parse_record_fn,
-                           num_epochs=1,
                            dtype=tf.float32,
                            datasets_num_private_threads=None,
                            drop_remainder=False,
@@ -122,12 +122,12 @@ def process_record_dataset(dataset,
         num_parallel_calls=tf.data.experimental.AUTOTUNE)
     dataset = dataset.batch(batch_size, drop_remainder=drop_remainder)
 
-    # Operations between the final prefetch and the get_next call to the iterator
-    # will happen synchronously during run time. We prefetch here again to
-    # background all of the above processing work and keep it out of the
-    # critical training path. Setting buffer_size to tf.data.experimental.AUTOTUNE
-    # allows DistributionStrategies to adjust how many batches to fetch based
-    # on how many devices are present.
+    # Operations between the final prefetch and the get_next call to the
+    # iterator will happen synchronously during run time. We prefetch here again
+    # to background all of the above processing work and keep it out of the
+    # critical training path. Setting buffer_size to
+    # tf.data.experimental.AUTOTUNE allows DistributionStrategies to adjust how
+    # many batches to fetch based on how many devices are present.
     dataset = dataset.prefetch(buffer_size=tf.data.experimental.AUTOTUNE)
 
     options = tf.data.Options()
@@ -144,11 +144,10 @@ def get_filenames(is_training, data_dir):
             os.path.join(data_dir, 'train-%05d-of-01024' % i)
             for i in range(_NUM_TRAIN_FILES)
         ]
-    else:
-        return [
-            os.path.join(data_dir, 'validation-%05d-of-00128' % i)
-            for i in range(128)
-        ]
+    return [
+        os.path.join(data_dir, 'validation-%05d-of-00128' % i)
+        for i in range(128)
+    ]
 
 
 def _parse_example_proto(example_serialized):
@@ -205,7 +204,7 @@ def _parse_example_proto(example_serialized):
 
     features = tf.io.parse_single_example(serialized=example_serialized,
                                           features=feature_map)
-    label = tf.cast(features['image/class/label'], dtype=tf.int32)
+    label = tf.cast(features['image/class/label'], tf.int32)
 
     xmin = tf.expand_dims(features['image/object/bbox/xmin'].values, 0)
     ymin = tf.expand_dims(features['image/object/bbox/ymin'].values, 0)
@@ -250,8 +249,8 @@ def parse_record(raw_record, im_size, is_training, dtype):
 
     # Subtract one so that labels are in [0, 1000), and cast to float32 for
     # Keras model.
-    label = tf.cast(tf.cast(tf.reshape(label, shape=[1]), dtype=tf.int32) - 1,
-                    dtype=tf.float32)
+    label = tf.cast(
+        tf.cast(tf.reshape(label, shape=[1]), tf.int32) - 1, tf.float32)
     return image, label
 
 
@@ -272,9 +271,9 @@ def get_val_dataset(data_dir, batch_size, im_size, preprocessing_fn, dtype):
     filenames = get_filenames(False, data_dir)
     dataset = tf.data.Dataset.from_tensor_slices(filenames)
     # Convert to individual records.
-    # cycle_length = 10 means that up to 10 files will be read and deserialized in
-    # parallel. You may want to increase this number if you have a large number of
-    # CPU cores.
+    # cycle_length = 10 means that up to 10 files will be read and deserialized
+    # in parallel. You may want to increase this number if you have a large
+    # number of CPU cores.
     dataset = dataset.interleave(
         tf.data.TFRecordDataset,
         cycle_length=tf.data.experimental.AUTOTUNE,
@@ -286,7 +285,6 @@ def get_val_dataset(data_dir, batch_size, im_size, preprocessing_fn, dtype):
                                   im_size=im_size,
                                   shuffle_buffer=_SHUFFLE_BUFFER,
                                   parse_record_fn=preprocessing_fn,
-                                  num_epochs=1,
                                   dtype=dtype,
                                   datasets_num_private_threads=None,
                                   drop_remainder=False,
@@ -297,7 +295,6 @@ def input_fn(is_training,
              data_dir,
              batch_size,
              im_size,
-             num_epochs=1,
              dtype=tf.float32,
              datasets_num_private_threads=None,
              parse_record_fn=parse_record,
@@ -343,17 +340,17 @@ def input_fn(is_training,
         dataset = dataset.shuffle(buffer_size=_NUM_TRAIN_FILES)
 
     # Convert to individual records.
-    # cycle_length = 10 means that up to 10 files will be read and deserialized in
-    # parallel. You may want to increase this number if you have a large number of
-    # CPU cores.
+    # cycle_length = 10 means that up to 10 files will be read and deserialized
+    # in parallel. You may want to increase this number if you have a large
+    # number of CPU cores.
     dataset = dataset.interleave(
         tf.data.TFRecordDataset,
         cycle_length=tf.data.experimental.AUTOTUNE,
         num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
     if is_training and training_dataset_cache:
-        # Improve training performance when training data is in remote storage and
-        # can fit into worker memory.
+        # Improve training performance when training data is in remote storage
+        # and can fit into worker memory.
         dataset = dataset.cache()
 
     return process_record_dataset(
@@ -363,7 +360,6 @@ def input_fn(is_training,
         im_size=im_size,
         shuffle_buffer=_SHUFFLE_BUFFER,
         parse_record_fn=parse_record_fn,
-        num_epochs=num_epochs,
         dtype=dtype,
         datasets_num_private_threads=datasets_num_private_threads,
         drop_remainder=drop_remainder,
@@ -411,7 +407,8 @@ def _decode_crop_and_flip(image_buffer, bbox, num_channels):
     target_height, target_width, _ = tf.unstack(bbox_size)
     crop_window = tf.stack([offset_y, offset_x, target_height, target_width])
 
-    # Use the fused decode and crop op here, which is faster than each in series.
+    # Use the fused decode and crop op here, which is faster than each in
+    # series.
     cropped = tf.image.decode_and_crop_jpeg(image_buffer,
                                             crop_window,
                                             channels=num_channels)
@@ -553,10 +550,10 @@ def _resize_image(image, height, width):
 def _random_distort_color(image):
     """randomly distort the color of a Tensor image.
 
-      Each color distortion is non-commutative and thus ordering of the color ops
-      matters. Ideally we would randomly permute the ordering of the color ops.
-      Rather then adding that level of complication, we select a distinct ordering
-      of color ops for each preprocessing thread.
+      Each color distortion is non-commutative and thus ordering of the color
+      ops matters. Ideally we would randomly permute the ordering of the color
+      ops. Rather then adding that level of complication, we select a distinct
+      ordering of color ops for each preprocessing thread.
 
       Args:
         image: 3-D Tensor containing single image in [0, 255].
@@ -569,10 +566,9 @@ def _random_distort_color(image):
     num_distort_cases = 1
     # scale image from 0 to 255 to 0 to 1 to use distort color
     image = tf.math.scalar_mul(1.0 / 255.0, image)
-    distorted_image = _apply_with_random_selector(
-        image,
-        lambda x, ordering: _distort_color(x, ordering),
-        num_cases=num_distort_cases)
+    distorted_image = _apply_with_random_selector(image,
+                                                  _distort_color,
+                                                  num_cases=num_distort_cases)
     return distorted_image
 
 
@@ -589,6 +585,9 @@ def _apply_with_random_selector(x, func, num_cases):
         The result of func(x, sel), where func receives the value of the
         selector as a python integer, but sel is sampled dynamically.
     """
+    # pylint must be disabled here as it incorrectly identifies tf API as
+    # explained in https://github.com/tensorflow/tensorflow/issues/43038.
+    # pylint: disable=unexpected-keyword-arg
     sel = tf.random.uniform([], maxval=num_cases, dtype=tf.int32)
     # Pass the real x only to one of the func calls.
     return control_flow_ops.merge([
@@ -601,10 +600,10 @@ def _apply_with_random_selector(x, func, num_cases):
 def _distort_color(image, color_ordering=0):
     """Distort the color of a Tensor image.
 
-      Each color distortion is non-commutative and thus ordering of the color ops
-      matters. Ideally we would randomly permute the ordering of the color ops.
-      Rather then adding that level of complication, we select a distinct ordering
-      of color ops for each preprocessing thread.
+      Each color distortion is non-commutative and thus ordering of the color
+      ops matters. Ideally we would randomly permute the ordering of the color
+      ops. Rather then adding that level of complication, we select a distinct
+      ordering of color ops for each preprocessing thread.
 
       Args:
         image: 3-D Tensor containing single image in [0, 1].
